==> haskell-typst-symbols-0.1.5-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst-symbols
version:              0.1.5
visibility:           public
id:                   typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
key:                  typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
license:              MIT
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/typst-symbols
synopsis:             Symbol and emoji lookup for typst language
description:
    This package defines symbol and emoji codes for the
    typst language (<https://typst.app>).

category:             Text
abi:                  0729765c9641fe0a090a109e65a26e61
exposed:              True
exposed-modules:      Typst.Emoji Typst.Shorthands Typst.Symbols
import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-symbols-0.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-symbols-0.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-symbols-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst-symbols
hs-libraries:         HStypst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
depends:              base-4.17.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-typst-symbols/html/typst-symbols.haddock

haddock-html:         /usr/share/doc/haskell-typst-symbols/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typst-symbols-0.1.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst-symbols
version:              0.1.6
visibility:           public
id:                   typst-symbols-0.1.6-8fTeUIeuBH16qqbNakBZL7
key:                  typst-symbols-0.1.6-8fTeUIeuBH16qqbNakBZL7
license:              MIT
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/typst-symbols
synopsis:             Symbol and emoji lookup for typst language
description:
    This package defines symbol and emoji codes for the
    typst language (<https://typst.app>).

category:             Text
abi:                  38f85675b3c7ba2eb83752de937617a6
exposed:              True
exposed-modules:      Typst.Emoji Typst.Shorthands Typst.Symbols
import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-symbols-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-symbols-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-symbols-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst-symbols
hs-libraries:         HStypst-symbols-0.1.6-8fTeUIeuBH16qqbNakBZL7
depends:              base-4.17.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-typst-symbols/html/typst-symbols.haddock

haddock-html:         /usr/share/doc/haskell-typst-symbols/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
